'A reference to the Phidget22.NET.dll must be added to new projects in VB.Net 
'From the "Project" menu select "Add Reference" 
'From the "Add Reference" window select the "Browse" tab 
'Browse to the directory you installed the Phidgets library to 
'The default is "C:\Program Files\Phidgets" 
'Select "Phidget22.NET.dll" and click "OK" 
'To view objects that have been added, select the "View" menu 
'Select "Object Browser" 
'Then expand the Phidget22.NET.dll item 



Imports Phidget22
Imports Phidget22.Events

Public Class Form1
    Dim WithEvents device As Phidget22.Accelerometer
    Dim open As ExampleUtils.ExampleUtils.CommandLineOpen
    Dim numAxes As Integer
    Dim errorBox As ErrorEventBox

    Public Sub New()
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Public Sub New(ByVal commandLine As String())
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        open.commandLine = commandLine
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        errorBox = New ErrorEventBox(Me)
        device = New Phidget22.Accelerometer()

        'open the device
        Dim phidgetParameters As ExampleUtils.commandLineData = open.parseCmdLine()

        Try 'set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.vb, you can check there to see them
            device.Channel = phidgetParameters.Channel 'selects the channel on the device to open
            device.DeviceSerialNumber = phidgetParameters.SerialNumber 'selects the device or hub to open
            device.HubPort = phidgetParameters.HubPort 'selects th eport on the hub to open
            device.IsHubPortDevice = phidgetParameters.isHubPortDevice 'is the device a port on a vint hub?

            If phidgetParameters.isRemote Then 'are we trying to open a remote device?
                device.IsRemote = True
                Net.EnableServerDiscovery(ServerType.Device) 'turn on network scan
                If phidgetParameters.Password <> vbNullString And phidgetParameters.ServerName <> vbNullString Then
                    Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password)
                End If
            Else
                device.IsLocal = True
            End If

            device.Open() 'open the device specified by the above parameters
        Catch ex As PhidgetException
            errorBox.addMessage("Error opening the device: " + ex.Message)
        End Try
    End Sub

    Private Sub device_Attach(ByVal sender As Object, ByVal e As Phidget22.Events.AttachEventArgs) Handles device.Attach
        'When the Phidget Accelerometer attaches update the form text boxes
        PhidgetInfoBox1.FillPhidgetInfo(CType(sender, Accelerometer))
        Dim attachedDevice As Accelerometer = CType(sender, Accelerometer)

        Try
            'initialize form controls.  change trigger and data interval must be set before the device will function
            dataIntervalTrk.Unit = " ms"
            dataIntervalTrk.minTxt = attachedDevice.MinDataInterval.ToString()
            dataIntervalTrk.maxTxt = attachedDevice.MaxDataInterval.ToString()
            dataIntervalTrk.Minimum = attachedDevice.MinDataInterval
            dataIntervalTrk.Maximum = attachedDevice.MaxDataInterval
            dataIntervalTrk.Value = attachedDevice.DataInterval

            changeTriggerTrk.Unit = "g"
            changeTriggerTrk.minTxt = attachedDevice.MinAccelerationChangeTrigger.ToString()
            changeTriggerTrk.maxTxt = attachedDevice.MaxAccelerationChangeTrigger.ToString()
            changeTriggerTrk.Minimum = attachedDevice.MinAccelerationChangeTrigger
            changeTriggerTrk.Maximum = attachedDevice.MaxAccelerationChangeTrigger
            changeTriggerTrk.Value = attachedDevice.AccelerationChangeTrigger

        Catch ex As PhidgetException
            errorBox.addMessage("Error initializing: " + ex.Message)
        End Try

        'the gauge control used had weird build artifacts, this code is necessary for the gui
        xGauge.GaugeRanges(0).EndValue = -2
        yGauge.GaugeRanges(0).EndValue = -2
        zGauge.GaugeRanges(0).EndValue = -2

        'initialize ui based on device type detected
        If (attachedDevice.DeviceID = DeviceID.PN_1008 Or attachedDevice.DeviceID = DeviceID.PN_1053) Then
            numAxes = 2
            zGauge.Visible = False
            zGaugeLbl.Visible = False
            zAxisLbl.Visible = False
            zAxisTxt.Visible = False
            xGauge.MinValue = -2
            yGauge.MinValue = -2
            xGauge.MaxValue = 2
            yGauge.MaxValue = 2
            legendBox1.Visible = False
            legendBox2.Visible = False
            enableGaugeRanges(xGauge, False)
            enableGaugeRanges(yGauge, False)
            enableGaugeRanges(zGauge, False)
            dataIntervalTrk.Enabled = False
        Else
            numAxes = 3
            zGauge.Visible = True
            zGaugeLbl.Visible = True
            zAxisLbl.Visible = True
            zAxisTxt.Visible = True
            xGauge.MinValue = -8
            yGauge.MinValue = -8
            xGauge.MaxValue = 8
            yGauge.MaxValue = 8
            legendBox1.Visible = True
            legendBox2.Visible = True
            enableGaugeRanges(xGauge, True)
            enableGaugeRanges(yGauge, True)
            enableGaugeRanges(zGauge, True)
            dataIntervalTrk.Enabled = True
            If (attachedDevice.DeviceID = DeviceID.PN_1059) Then
                dataIntervalTrk.Enabled = False
            Else
                Try
                    attachedDevice.DataInterval = 32 'faster is possible but not recommended as the gui has a tendency to bog down
                Catch ex As Exception
                    errorBox.addMessage("Error setting data interval: " + ex.Message)
                End Try
            End If
        End If

        outputBox.Visible = True
        settingsBox.Visible = True
        gaugeBox.Visible = True

    End Sub
    Private Sub device_Detach(ByVal sender As Object, ByVal e As Phidget22.Events.DetachEventArgs) Handles device.Detach
        outputBox.Visible = False
        settingsBox.Visible = False
        gaugeBox.Visible = False

        PhidgetInfoBox1.Clear()
    End Sub

    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        Application.DoEvents()
        If device.Attached Then
            device.Close()
        End If
    End Sub

    Private Sub device_Error(ByVal sender As Object, ByVal e As Phidget22.Events.ErrorEventArgs) Handles device.Error
        errorBox.addMessage("Error: " + e.Description)
    End Sub

    Private Sub device_AccelerationChange(ByVal sender As Object, ByVal e As Phidget22.Events.AccelerometerAccelerationChangeEventArgs) Handles device.AccelerationChange
        Try 'when new data comes in update the gui
            xAxisTxt.Text = e.Acceleration(0).ToString() + " g"
            xGauge.Value = e.Acceleration(0)
            yAxisTxt.Text = e.Acceleration(1).ToString() + " g"
            yGauge.Value = e.Acceleration(1)
            zAxisTxt.Text = e.Acceleration(2).ToString() + " g"
            zGauge.Value = e.Acceleration(2)
            timestamptxt.Text = e.Timestamp.ToString() + " ms"
        Catch ex As PhidgetException
            errorBox.addMessage("Error reading acceleration: " + ex.Message)
        End Try

    End Sub

    Private Sub dataIntervalTrk_Scroll(sender As Object, e As EventArgs) Handles dataIntervalTrk.LogScroll
        If (MouseButtons = MouseButtons.Left) Then
            Try
                device.DataInterval = CType(dataIntervalTrk.Value, Integer)
            Catch ex As Exception
                errorBox.addMessage("Error setting data interval: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub dataIntervalTrk_LogMouseUp(sender As Object, e As EventArgs) Handles dataIntervalTrk.LogMouseUp
        Try
            device.DataInterval = CType(dataIntervalTrk.Value, Integer)
        Catch ex As Exception
            errorBox.addMessage("Error setting data interval: " + ex.Message)
        End Try
    End Sub

    Private Sub changeTriggertrk_Scroll(sender As Object, e As EventArgs) Handles changeTriggerTrk.LogScroll
        If (MouseButtons = MouseButtons.Left) Then
            Try
                device.AccelerationChangeTrigger = CType(changeTriggerTrk.Value, Integer)
            Catch ex As Exception
                errorBox.addMessage("Error setting data interval: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub changeTriggerTrk_LogMouseUp(sender As Object, e As EventArgs) Handles changeTriggerTrk.LogMouseUp
        Try
            device.AccelerationChangeTrigger = CType(changeTriggerTrk.Value, Integer)
        Catch ex As Exception
            errorBox.addMessage("Error setting data interval: " + ex.Message)
        End Try
    End Sub

    Private Sub enableGaugeRanges(ByVal gauge As AGauge, ByVal state As Boolean) 'certain devices do not have a backup accelerometer
        If (state) Then
            gauge.GaugeRanges(0).Color = Color.LightCoral
            gauge.GaugeRanges(2).Color = Color.LightCoral
        Else
            gauge.GaugeRanges(0).Color = Color.Transparent
            gauge.GaugeRanges(2).Color = Color.Transparent
        End If
    End Sub
End Class



